@@ -16,7 +16,7 @@
  * I. Lee Hetherington (ilh@lcs.mit.edu)
  *
  * 1.5 and later versions contain changes by, and are maintained by,
- * Eddie Kohler <eddietwo@lcs.mit.edu>.
+ * Eddie Kohler <kohler@icir.org>.
  *
  * New change log in `NEWS'. Old change log:
  *
@@ -61,11 +61,15 @@
 #include <limits.h>
 #include <stdarg.h>
 #include <errno.h>
-#include "clp.h"
+#include <lcdf/clp.h>
 #include "t1lib.h"
 
 #define LINESIZE 512
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef unsigned char byte;
 
 static FILE *ifp;
@@ -231,7 +235,7 @@ static void eexec_byte(byte b)
 /* This function outputs a null-terminated string through possible eexec
    encryption. */
 
-static void eexec_string(char *string)
+static void eexec_string(const char *string)
 {
   while (*string)
     eexec_byte(*string++);
@@ -241,9 +245,9 @@ static void eexec_string(char *string)
    PFB format then flush current ASCII block and get ready for binary block.
    We start encryption with four random (zero) bytes. */
 
-static void eexec_start()
+static void eexec_start(char *string)
 {
-  eexec_string(line);
+  eexec_string("currentfile eexec\n");
   if (pfb && w.blocktyp != PFB_BINARY) {
     pfb_writer_output_block(&w);
     w.blocktyp = PFB_BINARY;
@@ -255,6 +259,7 @@ static void eexec_start()
   eexec_byte(0);
   eexec_byte(0);
   eexec_byte(0);
+  eexec_string(string);
 }
 
 /* 25.Aug.1999 -- Return 1 if this line actually looks like the start of a
@@ -341,7 +346,7 @@ static void eexec_end(void)
 /* This function is used by the binary search, bsearch(), for command names in
    the command table. */
 
-static int command_compare(const void *key, const void *item)
+static int CDECL command_compare(const void *key, const void *item)
 {
   return strcmp((const char *) key, ((const struct command *) item)->name);
 }
@@ -389,7 +394,7 @@ static void charstring_end()
 {
   byte *bp;
 
-  sprintf(line, "%d ", charstring_bp - charstring_buf);
+  sprintf(line, "%d ", (int) (charstring_bp - charstring_buf));
   eexec_string(line);
   sprintf(line, "%s ", cs_start);
   eexec_string(line);
@@ -544,7 +549,7 @@ static Clp_Option options[] = {
   { "pfb", 'b', PFB_OPT, 0, 0 },
   { "version", 0, VERSION_OPT, 0, 0 },
 };
-static char *program_name;
+static const char *program_name;
 
 void
 fatal_error(const char *message, ...)
@@ -595,17 +600,21 @@ Options:\n\
   -h, --help                  Print this message and exit.\n\
       --version               Print version number and warranty and exit.\n\
 \n\
-Report bugs to <eddietwo@lcs.mit.edu>.\n", program_name);
+Report bugs to <kohler@icir.org>.\n", program_name);
 }
 
+#ifdef __cplusplus
+}
+#endif
 
-int main(int argc, char **argv)
+
+int main(int argc, char *argv[])
 {
   char *p, *q, *r;
   
   Clp_Parser *clp =
-    Clp_NewParser(argc, argv, sizeof(options) / sizeof(options[0]), options);
-  program_name = (char *)Clp_ProgramName(clp);
+    Clp_NewParser(argc, (const char * const *)argv, sizeof(options) / sizeof(options[0]), options);
+  program_name = Clp_ProgramName(clp);
   
   /* interpret command line arguments using CLP */
   while (1) {
@@ -622,10 +631,8 @@ int main(int argc, char **argv)
 	fatal_error("output file already specified");
       if (strcmp(clp->arg, "-") == 0)
 	ofp = stdout;
-      else {
-	ofp = fopen(clp->arg, "w");
-	if (!ofp) fatal_error("%s: %s", clp->arg, strerror(errno));
-      }
+      else if (!(ofp = fopen(clp->arg, "w")))
+	fatal_error("%s: %s", clp->arg, strerror(errno));
       break;
       
      case PFB_OPT:
@@ -643,7 +650,7 @@ int main(int argc, char **argv)
       
      case VERSION_OPT:
       printf("t1asm (LCDF t1utils) %s\n", VERSION);
-      printf("Copyright (C) 1992-2002 I. Lee Hetherington, Eddie Kohler et al.\n\
+      printf("Copyright (C) 1992-2003 I. Lee Hetherington, Eddie Kohler et al.\n\
 This is free software; see the source for copying conditions.\n\
 There is NO warranty, not even for merchantability or fitness for a\n\
 particular purpose.\n");
@@ -657,10 +664,8 @@ particular purpose.\n");
 	goto output_file;
       if (strcmp(clp->arg, "-") == 0)
 	ifp = stdin;
-      else {
-	ifp = fopen(clp->arg, "r");
-	if (!ifp) fatal_error("%s: %s", clp->arg, strerror(errno));
-      }
+      else if (!(ifp = fopen(clp->arg, "r")))
+	fatal_error("%s: %s", clp->arg, strerror(errno));
       break;
       
      case Clp_Done:
@@ -719,15 +724,14 @@ particular purpose.\n");
     getline();
     
     if (!ever_active) {
-      if (strncmp(line, "currentfile eexec", 17) == 0) {
+      if (strncmp(line, "currentfile eexec", 17) == 0 && isspace(line[17])) {
 	/* Allow arbitrary whitespace after "currentfile eexec".
 	   Thanks to Tom Kacvinsky <tjk@ams.org> for reporting this.
 	   Note: strlen("currentfile eexec") == 17. */
-	for (p = line + 17; isspace(*p); p++) ;
-	if (!*p) {
-	  eexec_start();
-	  continue;
-	}
+	for (p = line + 18; isspace(*p); p++)
+	  ;
+	eexec_start(p);
+	continue;
       } else if (strncmp(line, "/lenIV", 6) == 0) {
 	lenIV = atoi(line + 6);
       } else if ((p = strstr(line, "string currentfile"))
